﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Reflection.Emit;
using System.Text;

using Xamarin.Forms;

namespace ChartSample
{
    public class DateTimeAxisLabelSample : ContentPage
    {
        SfChart chart;

        StackLayout stackLayout;
        public DateTimeAxisLabelSample()
        {
            stackLayout = new StackLayout();
            stackLayout.VerticalOptions = LayoutOptions.FillAndExpand;

            DataModel dataModel = new DataModel();

            chart = new SfChart();
            chart.VerticalOptions = LayoutOptions.FillAndExpand;

            DateTimeAxis dateTimeAxis = new DateTimeAxis();
            dateTimeAxis.LabelCreated += (s, e) =>
            {
                DateTime dateTime;

                if (Device.OS == TargetPlatform.iOS)
                    dateTime = (new DateTime(1970, 1, 1) + TimeSpan.FromDays(e.Position));
                else if (Device.OS == TargetPlatform.Android)
                    dateTime = (new DateTime(1970, 1, 1, 0, 0, 0, DateTimeKind.Utc) + TimeSpan.FromMilliseconds(e.Position)).ToLocalTime();
                else
                    dateTime = new DateTime(1900, 1, 1) + TimeSpan.FromMilliseconds(e.Position);

                if (dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Years)
                {
                    e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year;
                }

                else if (dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Months || dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Days)
                {
                    //e.LabelContent = dateTime.Day + "/" + getMonth(dateTime.Month);
                    e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year;
                }

                else if (dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Hours)
                {
                    if (dateTime.Hour != 0 && dateTime.Hour < 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + dateTime.Hour + "AM";
                    }
                    else if (dateTime.Hour == 0)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + "12AM";
                    }
                    else if (dateTime.Hour > 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour - 12) + "PM";
                    }
                    else
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour) + "PM";
                    }

                }

                else if (dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Minutes)
                {
                    if (dateTime.Hour != 0 && dateTime.Hour < 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + dateTime.Hour + ":" + dateTime.Minute + "AM";
                    }
                    else if (dateTime.Hour == 0)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + "12AM" + ":" + dateTime.Minute;
                    }
                    else if (dateTime.Hour > 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour - 12) + ":" + dateTime.Minute + "PM";
                    }
                    else
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour) + ":" + dateTime.Minute + "PM";
                    }
                }
                else if (dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Seconds || dateTimeAxis.GetActualIntervalType() == DateTimeIntervalType.Milliseconds)
                {
                    // e.LabelContent = dateTime.Hour + ":" + dateTime.Minute + ":" + dateTime.Second + "sec";
                    if (dateTime.Hour != 0 && dateTime.Hour < 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + dateTime.Hour + ":" + dateTime.Minute + ":" + dateTime.Second + "AM";
                    }
                    else if (dateTime.Hour == 0)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + "12" + ":" + dateTime.Minute + ":" + dateTime.Second + "AM";
                    }
                    else if (dateTime.Hour > 12)
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour - 12) + ":" + dateTime.Minute + ":" + dateTime.Second + "PM";
                    }
                    else
                    {
                        e.LabelContent = dateTime.Day + "/" + dateTime.Month + "/" + dateTime.Year + " " + (dateTime.Hour) + ":" + dateTime.Minute + ":" + dateTime.Second + "PM";
                    }
                }

            };
            dateTimeAxis.LabelStyle.LabelFormat = "dd/MM/yyyy";
            chart.PrimaryAxis = dateTimeAxis;

            NumericalAxis secondaryAxis = new NumericalAxis();
            chart.SecondaryAxis = secondaryAxis;

            LineSeries lineSeries = new LineSeries();
            lineSeries.EnableTooltip = true;
            lineSeries.StrokeWidth = 5;
            lineSeries.ItemsSource = dataModel.Data;
            chart.Series.Add(lineSeries);

            ChartZoomPanBehavior zoomPan = new ChartZoomPanBehavior();
            zoomPan.EnableSelectionZooming = true;
            chart.ChartBehaviors.Add(zoomPan);

            stackLayout.Children.Add(chart);
            Content = stackLayout;
        }
        string getMonth(int val)
        {
            switch (val)
            {
                case 1: return "Jan";
                case 2: return "Feb";
                case 3: return "Mar";
                case 4: return "Apr";
                case 5: return "May";
                case 6: return "Jun";
                case 7: return "Jul";
                case 8: return "Aug";
                case 9: return "Sep";
                case 10: return "Oct";
                case 11: return "Nov";
                case 12: return "Dec";
            }
            return null;
        }
    }
}
